@@ -28,7 +28,9 @@ usage:
 options:
     -h, --help
     -v, --version
-    -c, --config-file FILE  Use FILE as config file.
+    -c, --config-file FILE  Use FILE as config file. (Can also be set with the
+                            IA_CONFIG_FILE environment variable. The option takes
+                            precedence when both are used.)
     -l, --log               Turn on logging [default: False].
     -d, --debug             Turn on verbose logging [default: False].
     -i, --insecure          Use HTTP for all requests instead of HTTPS [default: false]
@@ -47,6 +49,7 @@ commands:
     list      List files in a given item.
     copy      Copy files in archive.org items.
     move      Move/rename files in archive.org items.
+    reviews   Submit/modify reviews for archive.org items.
 
 Documentation for 'ia' is available at:
 
@@ -83,6 +86,7 @@ cmd_aliases = dict(
     ls='list',
     cp='copy',
     mv='move',
+    re='reviews',
 )
 
 
@@ -175,5 +179,6 @@ def main():
         else:
             raise
 
+
 if __name__ == '__main__':
     main()
