@@ -2,7 +2,7 @@
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
-# Copyright (C) 2012-2019 Internet Archive
+# Copyright (C) 2012-2021 Internet Archive
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -21,7 +21,7 @@
 
 usage:
     ia download <identifier> [<file>]... [options]...
-    ia download <identifier> <file> --stdout [--retries=<retries>]
+    ia download <identifier> <file> --stdout [options]...
     ia download --itemlist=<file> [options]...
     ia download --search=<query> [options]...
     ia download --help
@@ -40,7 +40,9 @@ options:
     -P, --search-parameters=<key:value>...   Download items returned from a specified search query.
     -g, --glob=<pattern>                     Only download files whose filename matches the
                                              given glob pattern.
-    -f, --format=<format>...                 Only download files of the specified format(s).
+    -f, --format=<format>...                 Only download files of the specified format.
+                                             Use this option multiple times to download multiple
+                                             formats.
                                              You can use the following command to retrieve
                                              a list of file formats contained within a given
                                              item:
@@ -58,10 +60,11 @@ options:
     --no-change-timestamp                    Don't change the timestamp of downloaded files to reflect
                                              the source material.
     -p, --parameters=<key:value>...          Parameters to send with your query (e.g. `cnt=0`).
-    -a, --download-history                   Do not download any files from the history dir.
+    -a, --download-history                   Also download files from the history directory.
 """
 from __future__ import print_function, absolute_import
 import os
+from os.path import exists as dir_exists
 import sys
 
 import six
@@ -71,13 +74,6 @@ from schema import Schema, Use, Or, And, SchemaError
 from internetarchive.cli.argparser import get_args_dict
 
 
-def dir_exists(dir):
-    if os.path.exists(dir):
-        return True
-    else:
-        return False
-
-
 def main(argv, session):
     args = docopt(__doc__, argv=argv)
 
