@@ -256,7 +256,7 @@ class Item(BaseItem):
         :rtype: bool
         :returns: `True` if no tasks are pending, otherwise `False`.
         """
-        return all(x == 0 for x in self.task_summary(params, request_kwargs).values())
+        return all(x == 0 for x in self.get_task_summary(params, request_kwargs).values())
 
     def get_all_item_tasks(self, params=None, request_kwargs=None):
         """Get a list of all tasks for the item, pending and complete.
@@ -323,7 +323,7 @@ class Item(BaseItem):
 
         :type remove_derived: str
         :param remove_derived: (optional) You can use wildcards ("globs")
-                               to only remove *some* prior derivaties.
+                               to only remove *some* prior derivatives.
                                For example, "*" (typed without the
                                quotation marks) specifies that all
                                derivatives (in the item's top directory)
@@ -489,6 +489,26 @@ class Item(BaseItem):
         r.raise_for_status()
         return r
 
+    def get_review(self):
+        u = '{protocol}//{host}/services/reviews.php'.format(
+            protocol=self.session.protocol,
+            host=self.session.host)
+        p = dict(identifier=self.identifier)
+        a = S3Auth(self.session.access_key, self.session.secret_key)
+        r = self.session.get(u, params=p, auth=a)
+        r.raise_for_status()
+        return r
+
+    def delete_review(self):
+        u = '{protocol}//{host}/services/reviews.php'.format(
+            protocol=self.session.protocol,
+            host=self.session.host)
+        p = dict(identifier=self.identifier)
+        a = S3Auth(self.session.access_key, self.session.secret_key)
+        r = self.session.delete(u, params=p, auth=a)
+        r.raise_for_status()
+        return r
+
     def review(self, title, body, stars=None):
         u = '{protocol}//{host}/services/reviews.php'.format(
             protocol=self.session.protocol,
@@ -510,7 +530,7 @@ class Item(BaseItem):
 
         :type file_metadata: dict
         :param file_metadata: (optional) a dict of metadata for the
-                              given fille.
+                              given file.
         """
         return File(self, file_name, file_metadata)
 
@@ -1113,7 +1133,7 @@ class Item(BaseItem):
                debug=None,
                validate_identifier=None,
                request_kwargs=None):
-        """Upload files to an item. The item will be created if it
+        r"""Upload files to an item. The item will be created if it
         does not exist.
 
         :type files: str, file, list, tuple, dict
@@ -1138,9 +1158,9 @@ class Item(BaseItem):
         Uploading file objects:
 
             >>> import io
-            >>> f = io.BytesIO(b"some initial binary data: \\x00\\x01")
+            >>> f = io.BytesIO(b"some initial binary data: \x00\x01")
             >>> r = item.upload({'remote-name.txt': f})
-            >>> f = io.BytesIO(b"some more binary data: \\x00\\x01")
+            >>> f = io.BytesIO(b"some more binary data: \x00\x01")
             >>> f.name = 'remote-name.txt'
             >>> r = item.upload(f)
 
