@@ -2,7 +2,7 @@
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
-# Copyright (C) 2012-2019 Internet Archive
+# Copyright (C) 2012-2021 Internet Archive
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -24,9 +24,10 @@ internetarchive.session
 This module provides an ArchiveSession object to manage and persist
 settings across the internetarchive package.
 
-:copyright: (C) 2012-2019 by Internet Archive.
+:copyright: (C) 2012-2021 by Internet Archive.
 :license: AGPL 3, see LICENSE for more details.
 """
+
 from __future__ import absolute_import, unicode_literals
 
 import os
@@ -45,13 +46,14 @@ from requests.utils import default_headers
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3 import Retry
 from six.moves.urllib.parse import urlparse, unquote
+from requests.cookies import create_cookie
 
 from internetarchive import __version__, auth
 from internetarchive.config import get_config
 from internetarchive.item import Item, Collection
 from internetarchive.search import Search
 from internetarchive.catalog import Catalog, CatalogTask
-from internetarchive.utils import reraise_modify
+from internetarchive.utils import reraise_modify, parse_dict_cookies
 
 
 logger = logging.getLogger(__name__)
@@ -104,7 +106,16 @@ class ArchiveSession(requests.sessions.Session):
 
         self.config = get_config(config, config_file)
         self.config_file = config_file
-        self.cookies.update(self.config.get('cookies', {}))
+        for ck, cv in self.config.get('cookies', {}).items():
+            raw_cookie = '{}={}'.format(ck, cv)
+            cookie_dict = parse_dict_cookies(raw_cookie)
+            if not cookie_dict.get(ck):
+                continue
+            cookie = create_cookie(ck, cookie_dict[ck],
+                                   domain=cookie_dict.get('domain', '.archive.org'),
+                                   path=cookie_dict.get('path', '/'))
+            self.cookies.set_cookie(cookie)
+
         self.secure = self.config.get('general', {}).get('secure', True)
         self.host = self.config.get('general', {}).get('host', 'archive.org')
         if 'archive.org' not in self.host:
@@ -183,7 +194,7 @@ class ArchiveSession(requests.sessions.Session):
                                 connect=max_retries,
                                 read=max_retries,
                                 redirect=False,
-                                method_whitelist=Retry.DEFAULT_METHOD_WHITELIST,
+                                allowed_methods=Retry.DEFAULT_ALLOWED_METHODS,
                                 status_forcelist=status_forcelist,
                                 backoff_factor=1)
         self.http_adapter_kwargs['max_retries'] = max_retries
