@@ -49,7 +49,7 @@ def deep_update(d, u):
 
 
 def map2x(func, *iterables):
-    """map() function for Python 2/3 compatability"""
+    """map() function for Python 2/3 compatibility"""
     zipped = zip_longest(*iterables)
     if func is None:
         return zipped
@@ -213,7 +213,7 @@ def get_file_size(file_obj):
 
 
 def iter_directory(directory):
-    """Given a directory, yield all files recursivley as a two-tuple (filepath, s3key)"""
+    """Given a directory, yield all files recursively as a two-tuple (filepath, s3key)"""
     for path, dir, files in os.walk(directory):
         for f in files:
             filepath = os.path.join(path, f)
@@ -368,4 +368,51 @@ def is_valid_metadata_key(name):
     # are way more restrictive and only allow ".-A-Za-z_", possibly followed
     # by an index in square brackets e. g. [0].
     # On the other hand the Archive allows tags starting with the string "xml".
-    return bool(re.fullmatch('[A-Za-z][.\-0-9A-Za-z_]+(?:\[[0-9]+\])?', name))
+    return bool(re.match(r'^[A-Za-z][.\-0-9A-Za-z_]+(?:\[[0-9]+\])?$', name))
+
+
+def merge_dictionaries(dict0, dict1, keys_to_drop=None):
+    """Merge two dictionaries.
+
+       Items in `dict0` can optionally be dropped before the merge.
+
+       If equal keys exist in both dictionaries,
+       entries in`dict0` are overwritten.
+
+       :type dict0: dict
+       :param dict0: A base dictionary with the bulk of the items.
+
+       :type dict1: dict
+       :param dict1: Additional items which overwrite the items in `dict0`.
+
+       :type keys_to_drop: iterable
+       :param keys_to_drop: An iterable of keys to drop from `dict0` before the merge.
+
+       :rtype: dict
+       :returns: A merged dictionary.
+       """
+    new_dict = dict0.copy()
+    if keys_to_drop is not None:
+        for key in keys_to_drop:
+            new_dict.pop(key, None)
+    # Items from `dict1` take precedence over items from `dict0`.
+    new_dict.update(dict1)
+    return new_dict
+
+
+def parse_dict_cookies(value):
+    result = {}
+    for item in value.split(';'):
+        item = item.strip()
+        if not item:
+            continue
+        if '=' not in item:
+            result[item] = None
+            continue
+        name, value = item.split('=', 1)
+        result[name] = value
+    if 'domain' not in result:
+        result['domain'] = '.archive.org'
+    if 'path' not in result:
+        result['path'] = '/'
+    return result
